@@ -120,8 +120,7 @@ class RecipeDomain(Domain):
         return '{}.{}'.format('recipe', node.arguments[0])
 
     def get_objects(self):
-        for obj in self.data['recipes']:
-            yield(obj)
+        yield from self.data['recipes']
 
     def resolve_xref(self, env, fromdocname, builder, typ, target, node,
                      contnode):
