@@ -1,13 +1,11 @@
 """The Sphinx documentation toolchain."""
 
 # Keep this file executable as-is in Python 3!
-# (Otherwise getting the version out of it from setup.py is impossible.)
+# (Otherwise getting the version out of it when packaging is impossible.)
 
 import os
-import subprocess
 import warnings
 from os import path
-from subprocess import PIPE
 
 from .deprecation import RemovedInNextVersionWarning
 
@@ -18,9 +16,11 @@ if 'PYTHONWARNINGS' not in os.environ:
 # docutils.io using mode='rU' for open
 warnings.filterwarnings('ignore', "'U' mode is deprecated",
                         DeprecationWarning, module='docutils.io')
+warnings.filterwarnings('ignore', 'The frontend.Option class .*',
+                        DeprecationWarning, module='docutils.frontend')
 
-__version__ = '4.5.0'
-__released__ = '4.5.0'  # used when Sphinx builds its own docs
+__version__ = '5.3.0'
+__display_version__ = __version__  # used for command line version
 
 #: Version info for better programmatic use.
 #:
@@ -30,22 +30,26 @@ __released__ = '4.5.0'  # used when Sphinx builds its own docs
 #:
 #: .. versionadded:: 1.2
 #:    Before version 1.2, check the string ``sphinx.__version__``.
-version_info = (4, 5, 0, 'final', 0)
+version_info = (5, 3, 0, 'final', 0)
 
 package_dir = path.abspath(path.dirname(__file__))
 
-__display_version__ = __version__  # used for command line version
-if __version__.endswith('+'):
-    # try to find out the commit hash if checked out from git, and append
-    # it to __version__ (since we use this value from setup.py, it gets
-    # automatically propagated to an installed copy as well)
-    __display_version__ = __version__
-    __version__ = __version__[:-1]  # remove '+' for PEP-440 version spec.
+_in_development = False
+if _in_development:
+    # Only import subprocess if needed
+    import subprocess
+
     try:
-        ret = subprocess.run(['git', 'show', '-s', '--pretty=format:%h'],
-                             cwd=package_dir,
-                             stdout=PIPE, stderr=PIPE, encoding='ascii')
-        if ret.stdout:
-            __display_version__ += '/' + ret.stdout.strip()
-    except Exception:
-        pass
+        ret = subprocess.run(
+            ['git', 'show', '-s', '--pretty=format:%h'],
+            cwd=package_dir,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+            encoding='ascii',
+        ).stdout
+        if ret:
+            __display_version__ += '+/' + ret.strip()
+        del ret
+    finally:
+        del subprocess
+del _in_development
