@@ -1,12 +1,4 @@
-"""
-    sphinx.environment.collectors
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
-    The data collector components for sphinx.environment.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""The data collector components for sphinx.environment."""
 
 from typing import TYPE_CHECKING, Dict, List, Optional, Set
 
