@@ -1,12 +1,4 @@
-"""
-    sphinx.environment.collectors.dependencies
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
-    The dependencies collector components for sphinx.environment.
-
-    :copyright: Copyright 2007-2020 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""The dependencies collector components for sphinx.environment."""
 
 import os
 from os import path
