@@ -1,12 +1,4 @@
-"""
-    sphinx.search.ja
-    ~~~~~~~~~~~~~~~~
-
-    Japanese search language: includes routine to split words.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Japanese search language: includes routine to split words."""
 
 # Python Version of TinySegmenter
 # (http://chasen.org/~taku/software/TinySegmenter/)
@@ -54,8 +46,8 @@ class BaseSplitter:
 class MecabSplitter(BaseSplitter):
     def __init__(self, options: Dict) -> None:
         super().__init__(options)
-        self.ctypes_libmecab = None     # type: Any
-        self.ctypes_mecab = None        # type: Any
+        self.ctypes_libmecab: Any = None
+        self.ctypes_mecab: Any = None
         if not native_module:
             self.init_ctypes(options)
         else:
