@@ -1,12 +1,4 @@
-"""
-    sphinx.testing.comparer
-    ~~~~~~~~~~~~~~~~~~~~~~~
-
-    Sphinx test comparer for pytest
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Sphinx test comparer for pytest"""
 import difflib
 import pathlib
 from typing import Any, List, Union
