@@ -1,20 +1,11 @@
-"""
-    sphinx.testing.fixtures
-    ~~~~~~~~~~~~~~~~~~~~~~~
+"""Sphinx test fixtures for pytest"""
 
-    Sphinx test fixtures for pytest
-
-    :copyright: Copyright 2007-2020 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
-
-import os
 import subprocess
 import sys
 from collections import namedtuple
 from io import StringIO
 from subprocess import PIPE
-from typing import Any, Callable, Dict, Generator, Tuple
+from typing import Any, Callable, Dict, Generator, Optional, Tuple
 
 import pytest
 
@@ -31,18 +22,18 @@ DEFAULT_ENABLED_MARKERS = [
 
 
 def pytest_configure(config):
-    # register custom markers
+    """Register custom markers"""
     for marker in DEFAULT_ENABLED_MARKERS:
         config.addinivalue_line('markers', marker)
 
 
 @pytest.fixture(scope='session')
-def rootdir() -> str:
+def rootdir() -> Optional[str]:
     return None
 
 
 class SharedResult:
-    cache = {}  # type: Dict[str, Dict[str, str]]
+    cache: Dict[str, Dict[str, str]] = {}
 
     def store(self, key: str, app_: SphinxTestApp) -> Any:
         if key in self.cache:
@@ -67,30 +58,24 @@ class SharedResult:
 def app_params(request: Any, test_params: Dict, shared_result: SharedResult,
                sphinx_test_tempdir: str, rootdir: str) -> Tuple[Dict, Dict]:
     """
-    parameters that is specified by 'pytest.mark.sphinx' for
+    Parameters that are specified by 'pytest.mark.sphinx' for
     sphinx.application.Sphinx initialization
     """
 
     # ##### process pytest.mark.sphinx
 
-    if hasattr(request.node, 'iter_markers'):  # pytest-3.6.0 or newer
-        markers = request.node.iter_markers("sphinx")
-    else:
-        markers = request.node.get_marker("sphinx")
     pargs = {}
-    kwargs = {}  # type: Dict[str, Any]
+    kwargs: Dict[str, Any] = {}
 
-    if markers is not None:
-        # to avoid stacking positional args
-        for info in reversed(list(markers)):
-            for i, a in enumerate(info.args):
-                pargs[i] = a
-            kwargs.update(info.kwargs)
+    # to avoid stacking positional args
+    for info in reversed(list(request.node.iter_markers("sphinx"))):
+        for i, a in enumerate(info.args):
+            pargs[i] = a
+        kwargs.update(info.kwargs)
 
     args = [pargs[i] for i in sorted(pargs.keys())]
 
     # ##### process pytest.mark.test_params
-
     if test_params['shared_result']:
         if 'srcdir' in kwargs:
             raise pytest.Exception('You can not specify shared_result and '
@@ -115,18 +100,15 @@ def app_params(request: Any, test_params: Dict, shared_result: SharedResult,
 @pytest.fixture
 def test_params(request: Any) -> Dict:
     """
-    test parameters that is specified by 'pytest.mark.test_params'
+    Test parameters that are specified by 'pytest.mark.test_params'
 
     :param Union[str] shared_result:
        If the value is provided, app._status and app._warning objects will be
        shared in the parametrized test functions and/or test functions that
        have same 'shared_result' value.
-       **NOTE**: You can not specify shared_result and srcdir in same time.
+       **NOTE**: You can not specify both shared_result and srcdir.
     """
-    if hasattr(request.node, 'get_closest_marker'):  # pytest-3.6.0 or newer
-        env = request.node.get_closest_marker('test_params')
-    else:
-        env = request.node.get_marker('test_params')
+    env = request.node.get_closest_marker('test_params')
     kwargs = env.kwargs if env else {}
     result = {
         'shared_result': None,
@@ -143,7 +125,7 @@ def test_params(request: Any) -> Dict:
 def app(test_params: Dict, app_params: Tuple[Dict, Dict], make_app: Callable,
         shared_result: SharedResult) -> Generator[SphinxTestApp, None, None]:
     """
-    provides sphinx.application.Sphinx object
+    Provides the 'sphinx.application.Sphinx' object
     """
     args, kwargs = app_params
     app_ = make_app(*args, **kwargs)
@@ -163,7 +145,7 @@ def app(test_params: Dict, app_params: Tuple[Dict, Dict], make_app: Callable,
 @pytest.fixture(scope='function')
 def status(app: SphinxTestApp) -> StringIO:
     """
-    compat for testing with previous @with_app decorator
+    Back-compatibility for testing with previous @with_app decorator
     """
     return app._status
 
@@ -171,7 +153,7 @@ def status(app: SphinxTestApp) -> StringIO:
 @pytest.fixture(scope='function')
 def warning(app: SphinxTestApp) -> StringIO:
     """
-    compat for testing with previous @with_app decorator
+    Back-compatibility for testing with previous @with_app decorator
     """
     return app._warning
 
@@ -179,7 +161,7 @@ def warning(app: SphinxTestApp) -> StringIO:
 @pytest.fixture()
 def make_app(test_params: Dict, monkeypatch: Any) -> Generator[Callable, None, None]:
     """
-    provides make_app function to initialize SphinxTestApp instance.
+    Provides make_app function to initialize SphinxTestApp instance.
     if you want to initialize 'app' in your test function. please use this
     instead of using SphinxTestApp class directory.
     """
@@ -192,7 +174,7 @@ def make_app(test_params: Dict, monkeypatch: Any) -> Generator[Callable, None, N
         status, warning = StringIO(), StringIO()
         kwargs.setdefault('status', status)
         kwargs.setdefault('warning', warning)
-        app_ = SphinxTestApp(*args, **kwargs)  # type: Any
+        app_: Any = SphinxTestApp(*args, **kwargs)
         apps.append(app_)
         if test_params['shared_result']:
             app_ = SphinxTestAppWrapperForSkipBuilding(app_)
@@ -234,19 +216,34 @@ def if_graphviz_found(app: SphinxTestApp) -> None:
 @pytest.fixture(scope='session')
 def sphinx_test_tempdir(tmpdir_factory: Any) -> "util.path":
     """
-    temporary directory that wrapped with `path` class.
+    Temporary directory wrapped with `path` class.
     """
-    tmpdir = os.environ.get('SPHINX_TEST_TEMPDIR')  # RemovedInSphinx40Warning
-    if tmpdir is None:
-        tmpdir = tmpdir_factory.getbasetemp()
-
+    tmpdir = tmpdir_factory.getbasetemp()
     return util.path(tmpdir).abspath()
 
 
 @pytest.fixture
 def tempdir(tmpdir: str) -> "util.path":
     """
-    temporary directory that wrapped with `path` class.
-    this fixture is for compat with old test implementation.
+    Temporary directory wrapped with `path` class.
+    This fixture is for back-compatibility with old test implementation.
     """
     return util.path(tmpdir)
+
+
+@pytest.fixture
+def rollback_sysmodules():
+    """
+    Rollback sys.modules to its value before testing to unload modules
+    during tests.
+
+    For example, used in test_ext_autosummary.py to permit unloading the
+    target module to clear its cache.
+    """
+    try:
+        sysmodules = list(sys.modules)
+        yield
+    finally:
+        for modname in list(sys.modules):
+            if modname not in sysmodules:
+                sys.modules.pop(modname)
