@@ -112,7 +112,9 @@ class ReferencesResolver(SphinxPostTransform):
 
             node.replace_self(newnodes)
 
-    def resolve_anyref(self, refdoc: str, node: pending_xref, contnode: Element) -> Element:
+    def resolve_anyref(
+        self, refdoc: str, node: pending_xref, contnode: Element
+    ) -> Optional[Element]:
         """Resolve reference generated by the "any" role."""
         stddomain = self.env.get_domain('std')
         target = node['reftarget']
