@@ -1,12 +1,4 @@
-"""
-    sphinx.util.compat
-    ~~~~~~~~~~~~~~~~~~
-
-    modules for backward compatibility
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""modules for backward compatibility"""
 
 import sys
 from typing import TYPE_CHECKING, Any, Dict
