@@ -30,11 +30,6 @@ try:
 except ImportError:
     UnionType = None
 
-if False:
-    # For type annotation
-    from typing import Type  # NOQA # for python3.5.1
-
-
 # builtin classes that have incorrect __module__
 INVALID_BUILTIN_CLASSES = {
     Struct: 'struct.Struct',  # Before Python 3.9
@@ -74,8 +69,11 @@ InventoryItem = Tuple[str, str, str, str]
 Inventory = Dict[str, Dict[str, InventoryItem]]
 
 
-def get_type_hints(obj: Any, globalns: Dict = None, localns: Dict = None) -> Dict[str, Any]:
-    """Return a dictionary containing type hints for a function, method, module or class object.
+def get_type_hints(
+    obj: Any, globalns: Optional[Dict[str, Any]] = None, localns: Optional[Dict] = None
+) -> Dict[str, Any]:
+    """Return a dictionary containing type hints for a function, method, module or class
+    object.
 
     This is a simple wrapper of `typing.get_type_hints()` that does not raise an error on
     runtime.
@@ -215,6 +213,9 @@ def _restify_py37(cls: Optional[Type], mode: str = 'fully-qualified-except-typin
         return text
     elif isinstance(cls, typing._SpecialForm):
         return ':py:obj:`~%s.%s`' % (cls.__module__, cls._name)
+    elif sys.version_info >= (3, 11) and cls is typing.Any:
+        # handle bpo-46998
+        return f':py:obj:`~{cls.__module__}.{cls.__name__}`'
     elif hasattr(cls, '__qualname__'):
         if cls.__module__ == 'typing':
             return ':py:class:`~%s.%s`' % (cls.__module__, cls.__qualname__)
@@ -266,7 +267,7 @@ def _restify_py36(cls: Optional[Type], mode: str = 'fully-qualified-except-typin
             return reftext + '\\ [%s]' % param_str
         else:
             return reftext
-    elif isinstance(cls, typing.GenericMeta):
+    elif isinstance(cls, typing.GenericMeta):  # type: ignore[attr-defined]
         if module == 'typing':
             reftext = ':py:class:`~typing.%s`' % qualname
         else:
@@ -504,16 +505,16 @@ def _stringify_py36(annotation: Any, mode: str = 'fully-qualified-except-typing'
             return '%s%s[%s]' % (modprefix, qualname, param_str)
         else:
             return modprefix + qualname
-    elif isinstance(annotation, typing.GenericMeta):
+    elif isinstance(annotation, typing.GenericMeta):  # type: ignore[attr-defined]
         params = None
-        if annotation.__args__ is None or len(annotation.__args__) <= 2:  # type: ignore  # NOQA
-            params = annotation.__args__  # type: ignore
-        elif annotation.__origin__ == Generator:  # type: ignore
-            params = annotation.__args__  # type: ignore
+        if annotation.__args__ is None or len(annotation.__args__) <= 2:  # NOQA
+            params = annotation.__args__
+        elif annotation.__origin__ == Generator:
+            params = annotation.__args__
         else:  # typing.Callable
             args = ', '.join(stringify(arg, mode) for arg
-                             in annotation.__args__[:-1])  # type: ignore
-            result = stringify(annotation.__args__[-1])  # type: ignore
+                             in annotation.__args__[:-1])
+            result = stringify(annotation.__args__[-1])
             return '%s%s[[%s], %s]' % (modprefix, qualname, args, result)
         if params is not None:
             param_str = ', '.join(stringify(p, mode) for p in params)
