@@ -1,12 +1,12 @@
 
-import missing_module  # NOQA
-import missing_package1.missing_module1  # NOQA
-from missing_module import missing_name  # NOQA
-from missing_package2 import missing_module2  # NOQA
-from missing_package3.missing_module3 import missing_name  # NOQA
+import missing_module
+import missing_package1.missing_module1
+from missing_module import missing_name
+from missing_package2 import missing_module2
+from missing_package3.missing_module3 import missing_name
 
-import sphinx.missing_module4  # NOQA
-from sphinx.missing_module4 import missing_name2  # NOQA
+import sphinx.missing_module4
+from sphinx.missing_module4 import missing_name2
 
 
 @missing_name(int)
@@ -22,6 +22,10 @@ def func(arg: missing_module.Class):
 
 class TestAutodoc(object):
     """TestAutodoc docstring."""
+
+    #: docstring
+    Alias = missing_module2.Class
+
     @missing_name
     def decoratedMethod(self):
         """TestAutodoc::decoratedMethod docstring"""
@@ -34,3 +38,6 @@ class Inherited(missing_module.Class):
 
 
 sphinx.missing_module4.missing_function(len(missing_name2))
+
+#: docstring
+Alias = missing_module2.Class
