@@ -57,11 +57,11 @@ class EPUBElementTree:
 @pytest.mark.sphinx('epub', testroot='basic')
 def test_build_epub(app):
     app.build()
-    assert (app.outdir / 'mimetype').read_text() == 'application/epub+zip'
+    assert (app.outdir / 'mimetype').read_text(encoding='utf8') == 'application/epub+zip'
     assert (app.outdir / 'META-INF' / 'container.xml').exists()
 
     # toc.ncx
-    toc = EPUBElementTree.fromstring((app.outdir / 'toc.ncx').read_text())
+    toc = EPUBElementTree.fromstring((app.outdir / 'toc.ncx').read_text(encoding='utf8'))
     assert toc.find("./ncx:docTitle/ncx:text").text == 'Python'
 
     # toc.ncx / head
@@ -81,7 +81,7 @@ def test_build_epub(app):
     assert navlabel.text == 'The basic Sphinx documentation for testing'
 
     # content.opf
-    opf = EPUBElementTree.fromstring((app.outdir / 'content.opf').read_text())
+    opf = EPUBElementTree.fromstring((app.outdir / 'content.opf').read_text(encoding='utf8'))
 
     # content.opf / metadata
     metadata = opf.find("./idpf:metadata")
@@ -133,7 +133,7 @@ def test_build_epub(app):
     assert reference.get('href') == 'index.xhtml'
 
     # nav.xhtml
-    nav = EPUBElementTree.fromstring((app.outdir / 'nav.xhtml').read_text())
+    nav = EPUBElementTree.fromstring((app.outdir / 'nav.xhtml').read_text(encoding='utf8'))
     assert nav.attrib == {'lang': 'en',
                           '{http://www.w3.org/XML/1998/namespace}lang': 'en'}
     assert nav.find("./xhtml:head/xhtml:title").text == 'Table of Contents'
@@ -153,7 +153,7 @@ def test_epub_cover(app):
     app.build()
 
     # content.opf / metadata
-    opf = EPUBElementTree.fromstring((app.outdir / 'content.opf').read_text())
+    opf = EPUBElementTree.fromstring((app.outdir / 'content.opf').read_text(encoding='utf8'))
     cover_image = opf.find("./idpf:manifest/idpf:item[@href='%s']" % app.config.epub_cover[0])
     cover = opf.find("./idpf:metadata/idpf:meta[@name='cover']")
     assert cover
@@ -276,7 +276,7 @@ def test_epub_writing_mode(app):
     app.build()
 
     # horizontal / page-progression-direction
-    opf = EPUBElementTree.fromstring((app.outdir / 'content.opf').read_text())
+    opf = EPUBElementTree.fromstring((app.outdir / 'content.opf').read_text(encoding='utf8'))
     assert opf.find("./idpf:spine").get('page-progression-direction') == 'ltr'
 
     # horizontal / ibooks:scroll-axis
@@ -284,7 +284,7 @@ def test_epub_writing_mode(app):
     assert metadata.find("./idpf:meta[@property='ibooks:scroll-axis']").text == 'vertical'
 
     # horizontal / writing-mode (CSS)
-    css = (app.outdir / '_static' / 'epub.css').read_text()
+    css = (app.outdir / '_static' / 'epub.css').read_text(encoding='utf8')
     assert 'writing-mode: horizontal-tb;' in css
 
     # vertical
@@ -293,7 +293,7 @@ def test_epub_writing_mode(app):
     app.build()
 
     # vertical / page-progression-direction
-    opf = EPUBElementTree.fromstring((app.outdir / 'content.opf').read_text())
+    opf = EPUBElementTree.fromstring((app.outdir / 'content.opf').read_text(encoding='utf8'))
     assert opf.find("./idpf:spine").get('page-progression-direction') == 'rtl'
 
     # vertical / ibooks:scroll-axis
@@ -301,7 +301,7 @@ def test_epub_writing_mode(app):
     assert metadata.find("./idpf:meta[@property='ibooks:scroll-axis']").text == 'horizontal'
 
     # vertical / writing-mode (CSS)
-    css = (app.outdir / '_static' / 'epub.css').read_text()
+    css = (app.outdir / '_static' / 'epub.css').read_text(encoding='utf8')
     assert 'writing-mode: vertical-rl;' in css
 
 
@@ -309,7 +309,7 @@ def test_epub_writing_mode(app):
 def test_epub_anchor_id(app):
     app.build()
 
-    html = (app.outdir / 'index.xhtml').read_text()
+    html = (app.outdir / 'index.xhtml').read_text(encoding='utf8')
     assert ('<p id="std-setting-STATICFILES_FINDERS">'
             'blah blah blah</p>' in html)
     assert ('<span id="std-setting-STATICFILES_SECTION"></span>'
@@ -322,7 +322,7 @@ def test_epub_assets(app):
     app.builder.build_all()
 
     # epub_sytlesheets (same as html_css_files)
-    content = (app.outdir / 'index.xhtml').read_text()
+    content = (app.outdir / 'index.xhtml').read_text(encoding='utf8')
     assert ('<link rel="stylesheet" type="text/css" href="_static/css/style.css" />'
             in content)
     assert ('<link media="print" rel="stylesheet" title="title" type="text/css" '
@@ -335,7 +335,7 @@ def test_epub_css_files(app):
     app.builder.build_all()
 
     # epub_css_files
-    content = (app.outdir / 'index.xhtml').read_text()
+    content = (app.outdir / 'index.xhtml').read_text(encoding='utf8')
     assert '<link rel="stylesheet" type="text/css" href="_static/css/epub.css" />' in content
 
     # files in html_css_files are not outputted
@@ -350,7 +350,7 @@ def test_html_download_role(app, status, warning):
     app.build()
     assert not (app.outdir / '_downloads' / 'dummy.dat').exists()
 
-    content = (app.outdir / 'index.xhtml').read_text()
+    content = (app.outdir / 'index.xhtml').read_text(encoding='utf8')
     assert ('<li><p><code class="xref download docutils literal notranslate">'
             '<span class="pre">dummy.dat</span></code></p></li>' in content)
     assert ('<li><p><code class="xref download docutils literal notranslate">'
@@ -381,4 +381,4 @@ def test_run_epubcheck(app):
         except CalledProcessError as exc:
             print(exc.stdout.decode('utf-8'))
             print(exc.stderr.decode('utf-8'))
-            assert False, 'epubcheck exited with return code %s' % exc.returncode
+            raise AssertionError('epubcheck exited with return code %s' % exc.returncode)
