@@ -8,9 +8,29 @@ from subprocess import PIPE, CalledProcessError
 
 import pytest
 
+from sphinx.builders.gettext import Catalog, MsgOrigin
 from sphinx.util.osutil import cd
 
 
+def test_Catalog_duplicated_message():
+    catalog = Catalog()
+    catalog.add('hello', MsgOrigin('/path/to/filename', 1))
+    catalog.add('hello', MsgOrigin('/path/to/filename', 1))
+    catalog.add('hello', MsgOrigin('/path/to/filename', 2))
+    catalog.add('hello', MsgOrigin('/path/to/yetanother', 1))
+    catalog.add('world', MsgOrigin('/path/to/filename', 1))
+
+    assert len(list(catalog)) == 2
+
+    msg1, msg2 = list(catalog)
+    assert msg1.text == 'hello'
+    assert msg1.locations == [('/path/to/filename', 1),
+                              ('/path/to/filename', 2),
+                              ('/path/to/yetanother', 1)]
+    assert msg2.text == 'world'
+    assert msg2.locations == [('/path/to/filename', 1)]
+
+
 @pytest.mark.sphinx('gettext', srcdir='root-gettext')
 def test_build_gettext(app):
     # Generic build; should fail only when the builder is horribly broken.
@@ -23,7 +43,7 @@ def test_build_gettext(app):
     assert (app.outdir / 'subdir.pot').isfile()
 
     # regression test for issue #960
-    catalog = (app.outdir / 'markup.pot').read_text()
+    catalog = (app.outdir / 'markup.pot').read_text(encoding='utf8')
     assert 'msgid "something, something else, something more"' in catalog
 
 
@@ -40,7 +60,7 @@ def test_msgfmt(app):
         except CalledProcessError as exc:
             print(exc.stdout)
             print(exc.stderr)
-            assert False, 'msginit exited with return code %s' % exc.returncode
+            raise AssertionError('msginit exited with return code %s' % exc.returncode)
 
         assert (app.outdir / 'en_US.po').isfile(), 'msginit failed'
         try:
@@ -52,7 +72,7 @@ def test_msgfmt(app):
         except CalledProcessError as exc:
             print(exc.stdout)
             print(exc.stderr)
-            assert False, 'msgfmt exited with return code %s' % exc.returncode
+            raise AssertionError('msgfmt exited with return code %s' % exc.returncode)
 
         mo = app.outdir / 'en' / 'LC_MESSAGES' / 'test_root.mo'
         assert mo.isfile(), 'msgfmt failed'
@@ -76,7 +96,7 @@ def test_gettext_index_entries(app):
             return m.groups()[0]
         return None
 
-    pot = (app.outdir / 'index_entries.pot').read_text()
+    pot = (app.outdir / 'index_entries.pot').read_text(encoding='utf8')
     msgids = [_f for _f in map(msgid_getter, pot.splitlines()) if _f]
 
     expected_msgids = [
@@ -125,7 +145,7 @@ def test_gettext_disable_index_entries(app):
             return m.groups()[0]
         return None
 
-    pot = (app.outdir / 'index_entries.pot').read_text()
+    pot = (app.outdir / 'index_entries.pot').read_text(encoding='utf8')
     msgids = [_f for _f in map(msgid_getter, pot.splitlines()) if _f]
 
     expected_msgids = [
@@ -148,7 +168,7 @@ def test_gettext_template(app):
     app.builder.build_all()
     assert (app.outdir / 'sphinx.pot').isfile()
 
-    result = (app.outdir / 'sphinx.pot').read_text()
+    result = (app.outdir / 'sphinx.pot').read_text(encoding='utf8')
     assert "Welcome" in result
     assert "Sphinx %(version)s" in result
 
@@ -158,7 +178,7 @@ def test_gettext_template_msgid_order_in_sphinxpot(app):
     app.builder.build_all()
     assert (app.outdir / 'sphinx.pot').isfile()
 
-    result = (app.outdir / 'sphinx.pot').read_text()
+    result = (app.outdir / 'sphinx.pot').read_text(encoding='utf8')
     assert re.search(
         ('msgid "Template 1".*'
          'msgid "This is Template 1\\.".*'
@@ -176,7 +196,7 @@ def test_build_single_pot(app):
 
     assert (app.outdir / 'documentation.pot').isfile()
 
-    result = (app.outdir / 'documentation.pot').read_text()
+    result = (app.outdir / 'documentation.pot').read_text(encoding='utf8')
     assert re.search(
         ('msgid "Todo".*'
          'msgid "Like footnotes.".*'
