@@ -1,12 +1,4 @@
-"""
-    test_rst_domain
-    ~~~~~~~~~~~~~~~
-
-    Tests the reStructuredText domain.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Tests the reStructuredText domain."""
 
 from sphinx import addnodes
 from sphinx.addnodes import (desc, desc_addname, desc_annotation, desc_content, desc_name,
