@@ -114,6 +114,11 @@ def test_mock_decorator():
         def meth(self):
             pass
 
+        @classmethod
+        @mock.method_deco
+        def class_meth(cls):
+            pass
+
     @mock.class_deco
     class Bar:
         pass
@@ -124,6 +129,7 @@ def test_mock_decorator():
 
     assert undecorate(func).__name__ == "func"
     assert undecorate(Foo.meth).__name__ == "meth"
+    assert undecorate(Foo.class_meth).__name__ == "class_meth"
     assert undecorate(Bar).__name__ == "Bar"
     assert undecorate(Baz).__name__ == "Baz"
 
